"""
Tests.
"""
from .test_fields import TestMD5Field

__title__ = 'strawberry.tests'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = (
    'TestMD5Field',
)
