"""
Additional fields for(ever) Django.
"""

__title__ = 'django-strawberry'
__version__ = '0.1.1'
__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
__copyright__ = '2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = ('default_app_config',)

default_app_config = 'strawberry.apps.Config'
